@@ -197,15 +197,15 @@ void ICPslamWrapper::run3Dwindow()
 
 		// The maps:
 		{
-			opengl::CSetOfObjects::Ptr obj = metric_map_->getVisualization();
+			opengl::CSetOfObjects::Ptr obj = metric_map_.getVisualization();
 			view->insert(obj);
 
 			// now, only the point map in another OpenGL view:
 
 			// publish map
 			CSimplePointsMap* pm = nullptr;
-			if (metric_map_->countMapsByClass<CSimplePointsMap>())
-				pm = metric_map_->mapByClass<CSimplePointsMap>().get();
+			if (metric_map_.countMapsByClass<CSimplePointsMap>())
+				pm = metric_map_.mapByClass<CSimplePointsMap>().get();
 
 			if (pm) view_map->insert(pm->getVisualization());
 		}
@@ -337,18 +337,9 @@ void ICPslamWrapper::init()
 	sensorSub_.resize(lstSources.size());
 	for (size_t i = 0; i < lstSources.size(); i++)
 	{
-		if (lstSources[i].find("scan") != std::string::npos)
-		{
-			sensorSub_[i] = n_.subscribe(
-				lstSources[i], 1, &ICPslamWrapper::laserCallback, this);
-		}
-		else
-		{
-			std::cout
-				<< "Sensor topics should be 2d laser scans which inlude in the "
-				   "name the word scan "
-				<< "\n";
-		}
+		ROS_INFO_STREAM("Subscribing to: " << lstSources[i]);
+		sensorSub_[i] = n_.subscribe(
+			lstSources[i], 1, &ICPslamWrapper::laserCallback, this);
 	}
 
 	init3Dwindow();
@@ -359,29 +350,39 @@ void ICPslamWrapper::laserCallback(const sensor_msgs::LaserScan& _msg)
 	using namespace mrpt::maps;
 	using namespace mrpt::obs;
 
-	CObservation2DRangeScan::Ptr laser = CObservation2DRangeScan::Create();
-	if (laser_poses_.find(_msg.header.frame_id) == laser_poses_.end())
+	try
 	{
-		updateSensorPose(_msg.header.frame_id);
-	}
-	else
-	{
-		mrpt::poses::CPose3D pose = laser_poses_[_msg.header.frame_id];
-		mrpt::ros1bridge::fromROS(
-			_msg, laser_poses_[_msg.header.frame_id], *laser);
-		// CObservation::Ptr obs = CObservation::Ptr(laser);
-		observation = CObservation::Ptr(laser);
-		timeLastUpdate_ = laser->timestamp;
-		tictac.Tic();
-		mapBuilder.processObservation(observation);
-		t_exec = tictac.Tac();
-		ROS_INFO("Map building executed in %.03fms", 1000.0f * t_exec);
+		ROS_INFO_STREAM("2D LIDAR rx: " << _msg.header.frame_id);
 
-		run3Dwindow();
-		publishTF();
-		publishMapPose();
+		CObservation2DRangeScan::Ptr laser = CObservation2DRangeScan::Create();
+		if (laser_poses_.find(_msg.header.frame_id) == laser_poses_.end())
+		{
+			updateSensorPose(_msg.header.frame_id);
+		}
+
+		{
+			mrpt::poses::CPose3D pose = laser_poses_[_msg.header.frame_id];
+			mrpt::ros1bridge::fromROS(
+				_msg, laser_poses_[_msg.header.frame_id], *laser);
+			// CObservation::Ptr obs = CObservation::Ptr(laser);
+			observation = CObservation::Ptr(laser);
+			timeLastUpdate_ = laser->timestamp;
+			tictac.Tic();
+			mapBuilder.processObservation(observation);
+			t_exec = tictac.Tac();
+			ROS_INFO("Map building executed in %.03fms", 1000.0f * t_exec);
+
+			run3Dwindow();
+			publishTF();
+			publishMapPose();
+		}
+	}
+	catch (const std::exception& e)
+	{
+		ROS_ERROR_STREAM(e.what());
 	}
 }
+
 void ICPslamWrapper::publishMapPose()
 {
 	// get currently builded map
@@ -390,10 +391,10 @@ void ICPslamWrapper::publishMapPose()
 	// publish map
 	COccupancyGridMap2D* grid = nullptr;
 	CSimplePointsMap* pm = nullptr;
-	if (metric_map_->countMapsByClass<COccupancyGridMap2D>())
-		grid = metric_map_->mapByClass<COccupancyGridMap2D>().get();
-	if (metric_map_->countMapsByClass<CSimplePointsMap>())
-		pm = metric_map_->mapByClass<CSimplePointsMap>().get();
+	if (metric_map_.countMapsByClass<COccupancyGridMap2D>())
+		grid = metric_map_.mapByClass<COccupancyGridMap2D>().get();
+	if (metric_map_.countMapsByClass<CSimplePointsMap>())
+		pm = metric_map_.mapByClass<CSimplePointsMap>().get();
 
 	if (grid)
 	{
@@ -498,10 +499,10 @@ bool ICPslamWrapper::rawlogPlay()
 				// publish map
 				COccupancyGridMap2D* grid = nullptr;
 				CSimplePointsMap* pm = nullptr;
-				if (metric_map_->countMapsByClass<COccupancyGridMap2D>())
-					grid = metric_map_->mapByClass<COccupancyGridMap2D>().get();
-				if (metric_map_->countMapsByClass<CSimplePointsMap>())
-					pm = metric_map_->mapByClass<CSimplePointsMap>().get();
+				if (metric_map_.countMapsByClass<COccupancyGridMap2D>())
+					grid = metric_map_.mapByClass<COccupancyGridMap2D>().get();
+				if (metric_map_.countMapsByClass<CSimplePointsMap>())
+					pm = metric_map_.mapByClass<CSimplePointsMap>().get();
 
 				if (grid)
 				{
